@@ -3,7 +3,7 @@
 
 # The MIT License (MIT)
 
-# Copyright (c) 2012-2014 CNRS (Hervé BREDIN - http://herve.niderb.fr)
+# Copyright (c) 2012-2016 CNRS
 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -23,12 +23,15 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
+# AUTHORS
+# Hervé BREDIN - http://herve.niderb.fr
+
 from __future__ import unicode_literals
 
 """Label propagation (a.k.a. tagging) algorithms"""
 
-from label import HungarianTagger, ArgMaxTagger
-from segment import DirectTagger, ConservativeDirectTagger, ArgMaxDirectTagger
+from .label import HungarianTagger, ArgMaxTagger
+from .segment import DirectTagger, ConservativeDirectTagger, ArgMaxDirectTagger
 
 if __name__ == "__main__":
     import doctest
